@@ -8,16 +8,11 @@ import os
 import attr
 import pytest
 
-from openlineage.client import facet, run, set_producer
+from openlineage.client import facet, run
 from openlineage.client.run import RunState
 from openlineage.client.serde import Serde
 
 
-@pytest.fixture(scope="session", autouse=True)
-def _setup_producer() -> None:
-    set_producer("https://github.com/OpenLineage/OpenLineage/tree/0.0.1/client/python")
-
-
 def get_sorted_json(file_name: str) -> str:
     dirpath = os.path.dirname(os.path.realpath(__file__))
     with open(os.path.join(dirpath, file_name)) as f:
@@ -46,9 +41,10 @@ def test_full_core_event_serializes_properly() -> None:
         inputs=[],
         outputs=[],
         producer="https://github.com/OpenLineage/OpenLineage/tree/0.0.1/client/python",
+        schemaURL="https://openlineage.io/spec/1-0-5/OpenLineage.json#/definitions/RunEvent",
     )
 
-    assert Serde.to_json(run_event) == get_sorted_json("serde_example.json")
+    assert Serde.to_json(run_event) == get_sorted_json("serde_example_run_event.json")
 
 
 def test_run_id_uuid_check() -> None:
@@ -66,6 +62,7 @@ def test_run_event_type_validated() -> None:
         run.Run("69f4acab-b87d-4fc0-b27b-8ea950370ff3", {}),
         run.Job("default", "name"),
         "producer",
+        "schemaURL",
     )
     with pytest.raises(ValueError, match="'eventType' must be in <enum"):
         run.RunEvent(
@@ -74,6 +71,7 @@ def test_run_event_type_validated() -> None:
             valid_event.run,
             valid_event.job,
             valid_event.producer,
+            valid_event.schemaURL,
         )
 
     with pytest.raises(ValueError, match="Parsed date-time has to contain time: 2021-11-03"):
@@ -83,6 +81,7 @@ def test_run_event_type_validated() -> None:
             valid_event.run,
             valid_event.job,
             valid_event.producer,
+            valid_event.schemaURL,
         )
 
 
@@ -143,3 +142,66 @@ def test_serde_nested_nulls() -> None:
         )
         == '{"nested": []}'
     )
+
+
+def test_dataset_event() -> None:
+    dataset_event = run.DatasetEvent(
+        eventTime="2021-11-03T10:53:52.427343",
+        dataset=run.Dataset(
+            namespace="openlineage",
+            name="name",
+            facets={
+                "schema": facet.SchemaDatasetFacet(
+                    fields=[
+                        facet.SchemaField(name="a", type="string"),
+                        facet.SchemaField(name="b", type="string"),
+                    ],
+                ),
+            },
+        ),
+        producer="https://github.com/OpenLineage/OpenLineage/tree/0.0.1/client/python",
+        schemaURL="https://openlineage.io/spec/2-0-0/OpenLineage.json#/$defs/DatasetEvent",
+    )
+
+    assert Serde.to_json(dataset_event) == get_sorted_json("serde_example_dataset_event.json")
+
+
+def test_job_event() -> None:
+    job_event = run.JobEvent(
+        eventTime="2021-11-03T10:53:52.427343",
+        job=run.Job(
+            namespace="openlineage",
+            name="name",
+            facets={},
+        ),
+        inputs=[
+            run.Dataset(
+                namespace="openlineage",
+                name="dataset_a",
+                facets={
+                    "schema": facet.SchemaDatasetFacet(
+                        fields=[
+                            facet.SchemaField(name="a", type="string"),
+                        ],
+                    ),
+                },
+            ),
+        ],
+        outputs=[
+            run.Dataset(
+                namespace="openlineage",
+                name="dataset_b",
+                facets={
+                    "schema": facet.SchemaDatasetFacet(
+                        fields=[
+                            facet.SchemaField(name="a", type="string"),
+                        ],
+                    ),
+                },
+            ),
+        ],
+        producer="https://github.com/OpenLineage/OpenLineage/tree/0.0.1/client/python",
+        schemaURL="https://openlineage.io/spec/2-0-0/OpenLineage.json#/$defs/JobEvent",
+    )
+
+    assert Serde.to_json(job_event) == get_sorted_json("serde_example_job_event.json")
